"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateString = generateString;
exports.validateEmail = validateEmail;
exports.mergeConfig = exports.createProgressiveStepper = exports.utcDateToDate = exports.secondsToFormattedDistance = exports.createResizeEventFunc = exports.isJsonObject = exports.isJsonOfType = exports.filterOnTypes = exports.filterOnType = exports.recordToRestJson = exports.fromIdGetRid = exports.docFromId = exports.noAdminInHost = exports.locationHost = void 0;

var R = _interopRequireWildcard(require("ramda"));

var _immutabilityHelper = _interopRequireDefault(require("immutability-helper"));

var _jsonStringifyPrettyCompact = _interopRequireDefault(require("json-stringify-pretty-compact"));

var _fp = require("date-fns/esm/fp");

var _uiUtils = require("./ui-utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

// import formatDistance from 'date-fns/fp/formatDistance';
// import addSeconds from 'date-fns/fp/addSeconds';
// import debounce from 'lodash.debounce';
var debounce = require('lodash.debounce');

var locationHost = function locationHost(localhostFallback) {
  return document.location.host.startsWith('localhost') ? localhostFallback : document.location.host;
};

exports.locationHost = locationHost;

var noAdminInHost = function noAdminInHost(url) {
  return url.startsWith('admin.') ? url.replace('admin.', '') : url;
};

exports.noAdminInHost = noAdminInHost;

var docFromId = function docFromId(id) {
  return R.compose(R.find(R.propEq('id', id)), R.values, R.when(R.isNil, function () {}));
};

exports.docFromId = docFromId;

var fromIdGetRid = function fromIdGetRid(id) {
  return R.compose(R.prop('rid'), docFromId(id));
};

exports.fromIdGetRid = fromIdGetRid;
var recordToRestJson = R.curry(function (toOmit, doc) {
  return (0, _jsonStringifyPrettyCompact["default"])(R.omit(toOmit)(doc), {
    maxLength: 100
  });
} // JSON.stringify(R.omit(toOmit)(doc), undefined, 2),
);
exports.recordToRestJson = recordToRestJson;

var filterOnType = function filterOnType(type) {
  return R.filter(R.propEq('type', type));
};

exports.filterOnType = filterOnType;

var filterOnTypes = function filterOnTypes(types) {
  return R.filter(function (a) {
    return types.includes(a.type);
  });
};

exports.filterOnTypes = filterOnTypes;

var isJsonOfType = function isJsonOfType(type) {
  return R.tryCatch(R.compose(R.is(type), JSON.parse), R.F);
};

exports.isJsonOfType = isJsonOfType;
var isJsonObject = isJsonOfType(Object);
exports.isJsonObject = isJsonObject;
var createResizeEventFunc = R.memoizeWith( // force format break!
R.identity, function (limit) {
  return debounce(function () {
    return setTimeout(function () {
      return window.dispatchEvent(new Event('resize'));
    }, limit);
  });
});
/**
 * Generates a string of characters including numbers and letters in upper and lower case.
 * @param {number} length - The length of the string to generate.
 * @return {string} The generated string.
 */

exports.createResizeEventFunc = createResizeEventFunc;

function generateString() {
  var length = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 14;
  var charset = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
  var result = '';

  for (var i = 0, n = charset.length; i < length; i += 1) {
    result += charset.charAt(Math.floor(Math.random() * n));
  }

  return result;
}
/**
 * Validates an email address.
 * @param  {string} email - The email to validate
 * @return {boolean}
 */


function validateEmail(email) {
  // eslint-disable-next-line
  var re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
  return re.test(String(email).toLowerCase());
} // TODO: replace is not working, why?
// export const get = R.compose(
//   R.path,
//   R.map(x => (Number.isNaN(Number(x)) ? x : Number(x))),
//   R.split('.'),
//   str => str.replace(/\[/g, '.'),
//   R.replace(/\]/g, '.'),
// );


var secondsToFormattedDistance = R.compose(_uiUtils.toTitle, (0, _fp.formatDistance)(new Date()), function (x) {
  return (0, _fp.addSeconds)(x, new Date());
}, R.when(R.complement(R.is)(Number), function () {
  return 0;
}));
exports.secondsToFormattedDistance = secondsToFormattedDistance;

var utcDateToDate = function utcDateToDate(d) {
  return new Date(Date.UTC(d.getUTCFullYear(), d.getUTCMonth(), d.getUTCDate(), d.getUTCHours(), d.getUTCMinutes(), d.getUTCSeconds(), d.getUTCMilliseconds()));
};

exports.utcDateToDate = utcDateToDate;

var createProgressiveStepper = function createProgressiveStepper() {
  var intervalLength = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 10;
  var progressions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  return function (x) {
    var interval = Math.floor(x / intervalLength);
    var inInterval = x % intervalLength;
    var toMax = progressions.slice(0, interval);
    var offset = intervalLength * toMax.reduce(function (acc, a) {
      return acc + a;
    }, 0);
    return offset + progressions[interval] * inInterval;
  };
};

exports.createProgressiveStepper = createProgressiveStepper;
var oldConfigMerge = R.mergeDeepWithKey(function (key, left, right) {
  return R.includes(key, ['supported', 'menuItems', 'availableRoutes', 'services']) ? R.concat(left, right) : right;
});

var mergeConfig = function mergeConfig(baseConfig, updates) {
  var mergedConfig;

  try {
    mergedConfig = (0, _immutabilityHelper["default"])(baseConfig, updates);
  } catch (err) {
    mergedConfig = oldConfigMerge(baseConfig, updates);
  }

  return mergedConfig;
};

exports.mergeConfig = mergeConfig;